@@ -1,4 +1,4 @@
-__version__ = '0.3.1'
+__version__ = '0.5.4'
 
 import markdown as md
 
@@ -15,5 +15,6 @@ def marquedown(document: str, **kwargs):
     if kwargs.get('video', True):
         document = video(document)
         
-    document = md.markdown(document)
-    return document
\ No newline at end of file
+    html = md.markdown(document)
+
+    return html
\ No newline at end of file
