@@ -15,6 +15,10 @@ def _repl_citation(match: re.Match):
     quote = md.markdown(quote)
     source = md.markdown(source)
 
+    # Remove surrounding paragraph from source
+    if source.startswith('<p>') and source.endswith('</p>'):
+        source = source[3:-4]
+
     # Put everything into HTML
     return f'<blockquote>\n{quote}\n<cite>{source}</cite>\n</blockquote>'
 
