@@ -8,6 +8,7 @@ def _repl_youtube_video(match: re.Match):
     video_id, title = match.group(1, 2)
     return (
         f'<iframe '
+        f'class="mqd-video" '
         f'src="https://www.youtube.com/embed/{video_id}" '
         f'title={title or "" !r} '
         f'frameborder="0" '
@@ -29,6 +30,7 @@ def video(document: str):
         
         HTML:
             <iframe
+                class="mqd-video"
                 src="https://www.youtube.com/embed/VmAEkV5AYSQ"
                 title="An embedded YouTube video" frameborder="0"
                 allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
